# Tasks
The Tasks feature will take the objective that you give and break it down into smaller tasks by the Agent. The tasks will be executed in order, and the results will be returned once the task is complete. This feature is useful for automating tasks where you don't know all of the steps to complete it and are willing to let the AI Agent figure it out and do the work and research for you.